@@ -6,7 +6,7 @@ options:
     -h, --help
     -v, --verbose                   Be verbose.
     -d MIXDB, --mixdb MIXDB         Mixture database JSON file.
-    -i MIXID, --mixid MIXID         Mixture IDs JSON file.
+    -i MIXID, --mixid MIXID         Mixture ID(s) to generate and analyze. [default: *].
     -o OUTPUT, --output OUTPUT      Output HDF5 file.
     -s, --segsnr                    Save segsnr. [default: False].
 
@@ -14,8 +14,6 @@ Generate a SonusAI feature/truth file from a SonusAI mixture database.
 
 Inputs:
     MIXDB       A SonusAI mixture database JSON file.
-    MIXID       A JSON file containing a list of mixture IDs. The list should be named 'mixid'.
-                If no file is provided, then all mixtures in the database will be generated.
 
 Outputs:
     OUTPUT.h5   A SonusAI feature HDF5 file. Contains:
@@ -239,7 +237,7 @@ def main():
     from sonusai.mixture import get_samples_in_mixture
     from sonusai.mixture import get_transform_frames_in_mixture
     from sonusai.mixture import load_mixdb
-    from sonusai.mixture import load_mixid
+    from sonusai.utils import expand_range
     from sonusai.utils import grouper
     from sonusai.utils import human_readable_size
     from sonusai.utils import seconds_to_hms
@@ -249,7 +247,7 @@ def main():
 
     verbose = args['--verbose']
     mixdb_name = args['--mixdb']
-    mixid_name = args['--mixid']
+    mixid = args['--mixid']
     output_name = args['--output']
     compute_segsnr = args['--segsnr']
 
@@ -265,7 +263,10 @@ def main():
 
     logger.info(f'\nLoad mixture database from {mixdb_name}')
     mixdb = load_mixdb(name=mixdb_name)
-    mixid = load_mixid(name=mixid_name, mixdb=mixdb)
+    if mixid == '*':
+        mixid = list(range(len(mixdb.mixtures)))
+    else:
+        mixid = expand_range(mixid)
 
     mixdb_out, total_samples, total_transform_frames, total_feature_frames = init(mixdb=mixdb,
                                                                                   mixid=mixid,
