@@ -304,9 +304,11 @@ def genmixdb(file: str = None,
                     length += fs.feature_step_samples - int(length % fs.feature_step_samples)
                 total_duration += float(length) / sonusai.mixture.SAMPLE_RATE
 
-    target_sets *= len(mixdb.snrs) + len(mixdb.random_snrs)
-    total_duration *= len(mixdb.snrs) + len(mixdb.random_snrs)
+    total_snrs = len(mixdb.snrs) + len(mixdb.random_snrs)
+    target_sets *= total_snrs
+    total_duration *= total_snrs
     noise_sets = len(noise_files) * len(noise_augmentations) if mixdb.exhaustive_noise else 1
+    total_duration *= noise_sets
     total_mixtures = noise_sets * target_sets
     if logging:
         logger.info('')
