@@ -337,18 +337,9 @@ def validate_class(ontology_data: list, file: dict) -> bool:
     return valid
 
 
-def expand_range(s: str) -> list:
-    r = []
-    for i in s.split(','):
-        if '-' not in i:
-            r.append(int(i))
-        else:
-            l, h = map(int, i.split('-'))
-            r += range(l, h + 1)
-    return r
-
-
 def get_req_folds(folds: list, fold: str) -> list:
+    from sonusai.utils import expand_range
+
     if fold == '*':
         return folds
 
