@@ -4,7 +4,7 @@ usage: lsdb [-ht] [-i MIXID] [-c TID] MIXDB
 
 Options:
     -h, --help
-    -i MIXID, --mixid MIXID         Mixture ID to generate and analyze.
+    -i MIXID, --mixid MIXID         Mixture ID(s) to generate and analyze. [default: *].
     -c TID, --truth_index TID       Analyze mixtures that contain this truth index.
     -t, --targets                   List all target files.
 
@@ -24,21 +24,23 @@ import numpy as np
 
 from sonusai import logger
 from sonusai.mixture import MixtureDatabase
-from sonusai.utils import expand_range
 
 
 def lsdb(mixdb: MixtureDatabase,
-         mixid: int = None,
+         mixid: str = '*',
          datafile: str = None,
          truth_index: Union[int, None] = None,
          list_targets: bool = False) -> None:
     import h5py
 
     from sonusai import SonusAIError
+    from sonusai.mixture import calculate_snr_f_statistics
     from sonusai.mixture import SAMPLE_RATE
     from sonusai.mixture import get_feature_stats
     from sonusai.mixture import get_truth_indices_for_target
     from sonusai.queries import get_mixids_from_truth_index
+    from sonusai.utils import consolidate_range
+    from sonusai.utils import expand_range
     from sonusai.utils import print_class_count
     from sonusai.utils import print_mixture_details
     from sonusai.utils import seconds_to_hms
@@ -109,54 +111,30 @@ def lsdb(mixdb: MixtureDatabase,
         logger.info(f'Mixtures with truth index {truth_index}: {ids}')
         logger.info('')
 
-    if mixid is None:
-        mixid = '*'
-
     if mixid == '*':
-        mixid = np.array(range(len(mixdb.mixtures)))
-        logger.info(f'Mixture id list expanded from {mixid[0]} to {mixid[-1]} ...')
+        mixid = list(range(len(mixdb.mixtures)))
     else:
-        mixid = np.array(expand_range(str(mixid)))
+        mixid = expand_range(mixid)
 
     if len(mixid) == 1:
         print_mixture_details(mixdb=mixdb,
-                              mixid=int(mixid),
+                              mixid=mixid[0],
                               desc_len=desc_len,
                               print_fn=logger.info,
                               all_class_counts=True)
     else:
         if truth_f_shape is not None:
-            logger.info(f'Calculating statistics from .h5 file truth for {len(mixid)} mixtures ...')
+            logger.info(f'Calculating statistics from .h5 file truth for {len(mixid):,} mixtures'
+                        f' ({consolidate_range(mixid)})')
             with h5py.File(datafile, 'r') as f:
                 truth_f = np.array(f['truth_f'])
 
-            truth_mean = np.zeros((truth_f_shape[1]))
-            truth_var = np.zeros((truth_f_shape[1]))
-            truth_dbmean = np.zeros((truth_f_shape[1]))
-            truth_dbvar = np.zeros((truth_f_shape[1]))
-            for ci in range(truth_f_shape[1]):
-                tmp = truth_f[mixid, ci]
-                tmp2 = tmp[np.isfinite(tmp)]
-                if len(tmp2) == 0:
-                    logger.info(f'Warning: class {ci} has no finite values ...')
-                truth_mean[ci] = np.mean(tmp2)
-                truth_var[ci] = np.var(tmp2)
-                tmp3 = 10 * np.ma.log10(tmp2).filled(-np.inf)
-                tmp4 = tmp3[np.isfinite(tmp3)]
-                if len(tmp4) == 0:
-                    truth_dbmean[ci] = -np.inf
-                    truth_dbvar[ci] = -np.inf
-                else:
-                    truth_dbmean[ci] = np.mean(tmp4)
-                    truth_dbvar[ci] = np.var(tmp4)
-            logger.info('Truth mean:')
-            logger.info(truth_mean)
-            logger.info('Truth var:')
-            logger.info(truth_var)
-            logger.info('Truth dB mean:')
-            logger.info(truth_dbmean)
-            logger.info('Truth dB var:')
-            logger.info(truth_dbvar)
+            snr_mean, snr_std, snr_db_mean, snr_db_std = calculate_snr_f_statistics(truth_f)
+
+            logger.info('Truth')
+            logger.info(f'  {"mean":^8s}  {"std":^8s}  {"db_mean":^8s}  {"db_std":^8s}')
+            for c in range(len(snr_mean)):
+                logger.info(f'  {snr_mean[c]:8.2f}  {snr_std[c]:8.2f}  {snr_db_mean[c]:8.2f}  {snr_db_std[c]:8.2f}')
         else:
             logger.info(f'Generating truth for statistics of {len(mixdb.mixtures)} mixtures ...')
             # TBD run genmix on small batches of mixtures and calculate running statistics
