@@ -1,9 +1,7 @@
-from typing import List
-from typing import Union
-
 import numpy as np
 
-from sonusai.mixture import get_total_class_count
+from sonusai.mixture.mixdb import MixtureDatabase
+from sonusai.mixture.mixdb import MixtureID
 
 
 def calculate_class_weights_from_truth(truth: np.ndarray,
@@ -55,8 +53,8 @@ def calculate_class_weights_from_truth(truth: np.ndarray,
     return weights
 
 
-def calculate_class_weights_from_mixdb(mixdb: dict,
-                                       mixid: Union[str, List[int]] = ':',
+def calculate_class_weights_from_mixdb(mixdb: MixtureDatabase,
+                                       mixid: MixtureID = ':',
                                        other_weight: np.single = 1,
                                        other_index: int = -1) -> (np.ndarray, np.ndarray):
     """Calculate class weights using estimated feature counts from a mixture database.
@@ -75,17 +73,19 @@ def calculate_class_weights_from_mixdb(mixdb: dict,
         weights: Class weights. num_classes x 1
             Note: for Keras use dict(enumerate(weights))
     """
-    count = np.ceil(np.array(get_total_class_count(mixdb=mixdb, mixid=mixid)) / mixdb['feature_step_samples'])
-    if mixdb['truth_mutex'] and other_weight is not None and other_weight > 0:
+    from sonusai.mixture import get_total_class_count
+
+    count = np.ceil(np.array(get_total_class_count(mixdb=mixdb, mixid=mixid)) / mixdb.feature_step_samples)
+    if mixdb.truth_mutex and other_weight is not None and other_weight > 0:
         count[other_index] = count[other_index] / other_weight
     total_features = sum(count)
 
-    weights = np.empty(mixdb['num_classes'], dtype=np.single)
+    weights = np.empty(mixdb.num_classes, dtype=np.single)
     for n in range(len(weights)):
         if count[n] == 0:
             # Avoid sklearn problem with absent classes and assign non-existent classes a weight of 0.
             weights[n] = 0
         else:
-            weights[n] = total_features / (mixdb['num_classes'] * count[n])
+            weights[n] = total_features / (mixdb.num_classes * count[n])
 
     return count, weights
