@@ -1,14 +1,9 @@
 import numpy as np
-from sklearn.metrics import average_precision_score
-from sklearn.metrics import precision_recall_curve
-from sklearn.metrics import roc_auc_score
-from sklearn.metrics import roc_curve
-
-from sonusai import logger
 
 
 def calculate_optimal_thresholds(truth: np.ndarray,
                                  predict: np.ndarray,
+                                 timesteps: int = 0,
                                  truth_thr: float = 0.5) -> (np.ndarray, np.ndarray):
     """ Calculates optimal thresholds for each class from one-hot prediction and truth data
         (numpy float arrays) where both are one-hot probabilities (or quantized decisions)
@@ -21,26 +16,19 @@ def calculate_optimal_thresholds(truth: np.ndarray,
         Optional truth_thr is the decision threshold(s) applied to truth one-hot input thus allowing
         truth to optionally be continuous probabilities.  Default is 0.5.
     """
+    from sklearn.metrics import average_precision_score
+    from sklearn.metrics import precision_recall_curve
+    from sklearn.metrics import roc_auc_score
+    from sklearn.metrics import roc_curve
+
+    from sonusai import logger
+    from sonusai.utils import reshape_truth_predict
+
     if truth.shape != predict.shape:
         logger.error('Shape of truth and predict are not equal')
         exit()
 
-    num_classes = -1
-    # truth, predict can be either frames x num_classes, or frames x timesteps x num_classes
-    # in binary case dim may not exist, detect this and set num_classes == 1
-    if truth.ndim == 3 or (truth.ndim == 2 and num_classes == 1):
-        if truth.ndim == 2:  # has timesteps = truth.shape[1]
-            num_classes = 1
-        else:
-            num_classes = truth.shape[2]  # frames = truth.shape[0], timesteps = truth.shape[1]
-        # reshape to remove timestep dimension
-        truth = np.reshape(truth, (truth.shape[0] * truth.shape[1], truth.shape[2]))
-        predict = np.reshape(predict, (predict.shape[0] * predict.shape[1], predict.shape[2]))
-    else:
-        if truth.ndim == 1:  # no timesteps dimension, = 0
-            num_classes = 1
-        else:
-            num_classes = truth.shape[1]  # frames = truth.shape[0]
+    truth, predict, num_classes = reshape_truth_predict(truth, predict, timesteps)
 
     # Apply decision to truth input
     truthb = np.int8(truth >= truth_thr)
