@@ -4,12 +4,12 @@ from typing import Union
 import numpy as np
 import pandas as pd
 
-from sonusai.metrics.one_hot import one_hot
-from sonusai.mixture.get_mixid_data import get_mixid_data
+from sonusai.mixture.mixdb import MixtureDatabase
+from sonusai.mixture.mixdb import MixtureID
 
 
-def confusion_matrix_summary(mixdb: dict,
-                             mixid: Union[str, List[int]],
+def confusion_matrix_summary(mixdb: MixtureDatabase,
+                             mixid: MixtureID,
                              truth_f: np.ndarray,
                              predict: np.ndarray,
                              class_idx: int,
@@ -28,11 +28,14 @@ def confusion_matrix_summary(mixdb: dict,
 
        Returns pandas dataframes of confusion matrix cmdf and normalized confusion matrix cmndf.
     """
+    from sonusai.metrics import one_hot
+    from sonusai.mixture import get_mixid_data
+
     num_classes = truth_f.shape[1]
     ytrue, ypred = get_mixid_data(mixdb=mixdb, mixid=mixid, truth_f=truth_f, predict=predict)
 
     # Check pred_thr array or scalar and return final scalar pred_thr value
-    if not mixdb['truth_mutex'] and num_classes > 1:
+    if not mixdb.truth_mutex and num_classes > 1:
         if np.ndim(pred_thr) == 0 and pred_thr == 0:
             # multi-label pred_thr scalar 0 force to 0.5 default
             pred_thr = 0.5
@@ -49,14 +52,14 @@ def confusion_matrix_summary(mixdb: dict,
                 # multi-label pred_thr array scalar set = array[class_idx]
                 pred_thr = pred_thr[class_idx]
 
-    if len(mixdb['class_labels']) == num_classes:
-        class_names = mixdb['class_labels']
+    if len(mixdb.class_labels) == num_classes:
+        class_names = mixdb.class_labels
     else:
         class_names = ([f'Class {i}' for i in range(1, num_classes + 1)])
 
     class_nums = ([f'{i}' for i in range(1, num_classes + 1)])
 
-    if mixdb['truth_mutex']:
+    if mixdb.truth_mutex:
         # single-label mode force to argmax mode
         pred_thr = 0
         _, _, cm, cmn, _, _ = one_hot(ytrue, ypred, pred_thr, truth_thr, timesteps)
