@@ -1,46 +1,38 @@
-import warnings
+from typing import Union
 
 import numpy as np
-from sklearn.metrics import average_precision_score
-from sklearn.metrics import confusion_matrix
-from sklearn.metrics import multilabel_confusion_matrix
-from sklearn.metrics import precision_recall_fscore_support
-from sklearn.metrics import roc_auc_score
-
-from sonusai import logger
-from sonusai.utils.reshape import reshape_truth_predict
 
 
 def one_hot(truth: np.ndarray,
             predict: np.ndarray,
-            predict_thr: float = 0,
+            predict_thr: Union[float, np.ndarray] = 0,
             truth_thr: float = 0.5,
             timesteps: int = -1) -> (np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray):
     """ Calculates metrics from one-hot prediction and truth data (numpy float arrays) where
         both are one-hot probabilities (or quantized decisions) for each class
         with size frames x num_classes or frames x timesteps x num_classes.
-        For metrics that require it, truth and pred decisions will be made using threshold >= pthr.
-        Some metrics like AP and AUC do not depend on pthr for predict, but still use truth >= pthr
+        For metrics that require it, truth and pred decisions will be made using threshold >= predict_thr.
+        Some metrics like AP and AUC do not depend on predict_thr for predict, but still use truth >= predict_thr
 
-        pred_thr sets the decision threshold(s) applied to predict data for some metrics, thus allowing
-        the input to be continuous probabilities, for AUC-type metrics and root mean square error (rmse).
+        predict_thr sets the decision threshold(s) applied to predict data for some metrics, thus allowing
+        the input to be continuous probabilities, for AUC-type metrics and root-mean-square error (rmse).
         1. Default = 0 (multiclass or binary) which infers:
            binary (nclass = 1)         use >= 0.5 for truth and pred (same as argmax() for binary)
            multi-class/single-label    if truth_mutex= = true, use argmax() used on both truth and pred
-           note multi-label metrics are disabled for pthr = 0, must set pthr > 0
+           note multi-label metrics are disabled for predict_thr = 0, must set predict_thr > 0
 
-        2. pthr > 0 (multilabel or binary) scalar or a vector num_class x 1 then use
-           pthr as a binary decision threshold in each class:
-           binary (nclass = 1)         use >= pthr[0] for pred and pthr[num_classes+1] for truth
+        2. predict_thr > 0 (multilabel or binary) scalar or a vector num_class x 1 then use
+           predict_thr as a binary decision threshold in each class:
+           binary (nclass = 1)         use >= predict_thr[0] for pred and predict_thr[num_classes+1] for truth
                                        if it exists, else use >= 0.5 for truth
-           multi-label                 use >= pthr for pred if scalar, or pthr[class_idx] if vector
-                                       use >= pthr[num_classes+1] for truth if exists, else 0.5
-           note multi-class/single-label inputs are meaningless in this mode, use pthr = 0 argmax mode
+           multi-label                 use >= predict_thr for pred if scalar, or predict_thr[class_idx] if vector
+                                       use >= predict_thr[num_classes+1] for truth if exists, else 0.5
+           note multi-class/single-label inputs are meaningless in this mode, use predict_thr = 0 argmax mode
 
-        num_classes is inferred from 1D, 2D or 3D truth inputs by default (default tstep = -1 or 0).
-        Only set tstep > 0 in case of ambiguous binary 2D case where input frames x timesteps,
+        num_classes is inferred from 1D, 2D or 3D truth inputs by default (default timesteps = -1 or 0).
+        Only set timesteps > 0 in case of ambiguous binary 2D case where input frames x timesteps,
         then it must set to the number of timesteps = TSTEPS (which will be > 0).
-        It is safe to always set tstep <= 0 for binary inputs, and if truth_shape[2] exists
+        It is safe to always set timesteps <= 0 for binary inputs, and if truth_shape[2] exists
 
         returns metrics over all frames + timesteps:
         mcm      num_classes x 2 x 2         multiclass confusion matrix count ove
@@ -49,6 +41,17 @@ def one_hot(truth: np.ndarray,
         rmse:    num_classes x 1             RMS error over all frames + timesteps, before threshold decision
         mavg:    3x8 averages                macro,micro,weighted [PPV, TPR, F1, FPR, ACC, mAP, mAUC, TPSUM]
     """
+    import warnings
+
+    from sklearn.metrics import average_precision_score
+    from sklearn.metrics import confusion_matrix
+    from sklearn.metrics import multilabel_confusion_matrix
+    from sklearn.metrics import precision_recall_fscore_support
+    from sklearn.metrics import roc_auc_score
+
+    from sonusai import logger
+    from sonusai.utils import reshape_truth_predict
+
     if truth.shape != predict.shape:
         logger.error('Shape of truth and predict are not equal')
         exit()
@@ -58,7 +61,7 @@ def one_hot(truth: np.ndarray,
     # Regression metric root-mean-square-error always works
     rmse = np.sqrt(np.mean(np.square(truth - predict), axis=0))
 
-    # Calc default predict decision thresholds based on mode
+    # Calculate default predict decision thresholds based on mode
     if not np.ndim(predict_thr) and predict_thr == 0:
         # if scalar and 0, set defaults
         if num_classes == 1:
@@ -79,25 +82,15 @@ def one_hot(truth: np.ndarray,
                 # user specified binary or multi-label scalar
                 predict_thr = np.atleast_1d(predict_thr)
 
-    # if predict_thr[0] == 0 and num_classes > 1:  # if scalar
-    #     pthr = 0.5  # multiclass, single-label (argmax) or multilabel case default
-    # else:
-    #     if num_classes == 1 and predict_thr[0] == 0:
-    #         pthr = 0.5  # binary case default >= 0.5 which is equiv to argmax()
-    #     else:
-    #         pthr = pthr  # any case using specified threshold
-
     # Convert continuous probabilities to binary via argmax() or threshold comparison
     # and create labels of int encoded (0:num_classes-1), and then equivalent one-hot
     if num_classes == 1:  # If binary
-        binary_mode = True
         labels = ([i for i in range(0, 2)])  # int encoded 0,1
         plabel = np.int8(predict >= predict_thr)  # frames x 1, default 0.5 is equiv. to argmax()
         tlabel = np.int8(truth >= truth_thr)  # frames x 1
         predb = plabel
         truthb = tlabel
     else:
-        binary_mode = False
         labels = ([i for i in range(0, num_classes)])  # int encoded 0,...,num_classes-1
         if predict_thr[0] == 0:  # multiclass single-label (mutex), use argmax
             plabel = np.argmax(predict, axis=-1)  # frames x 1 labels
@@ -153,7 +146,7 @@ def one_hot(truth: np.ndarray,
         ACC = (TP + TN) / (TP + TN + FP + FN + eps)
         # True positive rate, sensitivity, recall, hit rate (note eps in numerator)
         # When ``true positive + false negative == 0``, recall is undefined, set to 0
-        TPR = (TP) / (TP + FN + eps)
+        TPR = TP / (TP + FN + eps)
         # Precision, positive predictive value
         # When ``true positive + false positive == 0``, precision is undefined, set to 0
         PPV = TP / (TP + FP + eps)
@@ -168,9 +161,9 @@ def one_hot(truth: np.ndarray,
         # Matthew correlation coefficient
         MCC = (TP * TN - FP * FN) / (np.sqrt((TP + FP) * (TP + FN) * (TN + FP) * (TN + FN)) + eps)
         # Num. negatives total (truth), also = TN+FP denom of FPR
-        NT = sum(mcm[nci, 0,])
+        NT = sum(mcm[nci, 0, :])
         # Num. positives total (truth), also = FN+TP denom of TPR, precision
-        PT = sum(mcm[nci, 1,])
+        PT = sum(mcm[nci, 1, :])
         # Average Precision also called area under the PR curve AUCPR and
         # AUC ROC curve using binary-ized truth and continuous prediction probabilities
         # sklearn returns nan if no active truth in a class but w/un-suppressible div-by-zero warning
@@ -187,10 +180,10 @@ def one_hot(truth: np.ndarray,
             # # Optimal threshold from PR curve, optimizes f-score
             # precision, recall, thresholds = precision_recall_curve(truthb[:, nci], predict[:, nci])
             # fscore = (2 * precision * recall) / (precision + recall)
-            # ix = argmax(fscore)  # index of largest f1 score
+            # ix = np.argmax(fscore)  # index of largest f1 score
             # threshold_optpr[nci] = thresholds[ix]
 
-        metrics[nci] = [ACC, TPR, PPV, TNR, FPR, HITFA, F1, MCC, NT, PT, TP, FP, AP, AUC]
+        metrics[nci, :] = [ACC, TPR, PPV, TNR, FPR, HITFA, F1, MCC, NT, PT, TP, FP, AP, AUC]
 
     # Calculate averages into single array, 3 types for now Macro, Micro, Weighted
     mavg = np.zeros((3, 8), dtype=np.single)
@@ -199,8 +192,8 @@ def one_hot(truth: np.ndarray,
     # macro average [PPV, TPR, F1, FPR, ACC, mAP, mAUC, TPSUM]
     with warnings.catch_warnings():
         warnings.filterwarnings(action='ignore', message='Mean of empty slice')
-        mavg[0,] = [np.mean(metrics[:, 2]), np.mean(metrics[:, 1]), np.mean(metrics[:, 6]), np.mean(metrics[:, 4]),
-                    np.mean(metrics[:, 0]), np.nanmean(metrics[:, 12]), np.nanmean(metrics[:, 13]), s]
+        mavg[0, :] = [np.mean(metrics[:, 2]), np.mean(metrics[:, 1]), np.mean(metrics[:, 6]), np.mean(metrics[:, 4]),
+                      np.mean(metrics[:, 0]), np.nanmean(metrics[:, 12]), np.nanmean(metrics[:, 13]), s]
 
     # micro average, micro-F1 = micro-precision = micro-recall = accuracy
     if num_classes > 1:
@@ -222,7 +215,7 @@ def one_hot(truth: np.ndarray,
             miauc = np.NaN
 
         # [miPPV, miTPR, miF1, miFPR, miACC, miAP, miAUC, TPSUM]
-        mavg[1,] = [pm, rm, f1m, fpm, accm, miap, miauc, s]  # specific format, last 3 are unique
+        mavg[1, :] = [pm, rm, f1m, fpm, accm, miap, miauc, s]  # specific format, last 3 are unique
 
         # weighted average TBD
         wp, wr, wf1, _ = precision_recall_fscore_support(truthb, predb, average='weighted', zero_division=0)
@@ -239,7 +232,7 @@ def one_hot(truth: np.ndarray,
 
         mavg[2, :] = [wp, wr, wf1, 0, 0, wap, wauc, s]
     else:  # binary case, all are same
-        mavg[1,] = mavg[0,]
-        mavg[2,] = mavg[0,]
+        mavg[1, :] = mavg[0, :]
+        mavg[2, :] = mavg[0, :]
 
     return mcm, metrics, cm, cmn, rmse, mavg
