@@ -48,6 +48,8 @@ from sonusai.mixture.feature import get_feature_stats
 from sonusai.mixture.feature import get_ft_from_file
 from sonusai.mixture.feature import read_feature_data
 from sonusai.mixture.log_duration_and_sizes import log_duration_and_sizes
+from sonusai.mixture.mapped_snr_f import calculate_mapped_snr_f
+from sonusai.mixture.mapped_snr_f import calculate_snr_f_statistics
 from sonusai.mixture.mixdb import Augmentation
 from sonusai.mixture.mixdb import Augmentations
 from sonusai.mixture.mixdb import AugmentedTarget
