@@ -9,14 +9,18 @@ from sonusai.mixture.mixdb import MixtureID
 from sonusai.mixture.mixdb import Mixtures
 
 
-def get_class_count(mixdb: MixtureDatabase, mixture: Mixture, target_audio: List[np.ndarray]) -> ClassCount:
+def get_class_count(mixdb: MixtureDatabase,
+                    mixture: Mixture,
+                    target_audios: List[np.ndarray],
+                    noise_audio: np.ndarray) -> ClassCount:
     """Computes the number of samples for which each truth index is active for a given sample-based truth input."""
     from sonusai.mixture import get_class_weights_threshold
     from sonusai.mixture import generate_truth
 
     truth = generate_truth(mixdb=mixdb,
                            mixture=mixture,
-                           target_audio=target_audio)
+                           target_audios=target_audios,
+                           noise_audio=noise_audio)
 
     class_weights_threshold = get_class_weights_threshold(mixdb)
 
@@ -53,7 +57,3 @@ def compute_total_class_count(mixdb: MixtureDatabase, mixtures: Mixtures) -> Cla
         total_class_count[-1] = sum([sub.samples for sub in mixtures]) - sum(total_class_count)
 
     return total_class_count
-
-# def get_class_count_metrics_for_class(mixdb: MixtureDatabase, class_index: int) -> (int, int):
-#     """TODO"""
-#     pass
