@@ -17,3 +17,7 @@ class Segment:
         if amount >= self.length:
             raise ValueError(f'trim amount greater than or equal to length')
         self.length -= amount
+
+
+def get_slices(segment: Segment, start: int) -> (slice, slice):
+    return segment.get_slice(), slice(start, start + segment.length)
